@@ -1,4 +1,4 @@
-// Mousetraps application. Copyright (C) 1996 Santa Fe Institute.
+// Mousetraps application. Copyright (C) 1996-1998 Santa Fe Institute.
 // This library is distributed without any warranty; without even the
 // implied warranty of merchantability or fitness for a particular purpose.
 // See file LICENSE for details and terms of copying.
@@ -25,19 +25,20 @@
 //    that is unique to the creation of a MousetrapObserverSwarm.
 //    This method is actually invoked in main.m
 
-+createBegin: (id) aZone {
++ createBegin: aZone
+{
   MousetrapObserverSwarm * obj;
   id <ProbeMap> probeMap;
-
+  
   // invoke our superClass createBegin to allocate ourselves.
   // obj is the allocated ObserverSwarm
   
   obj = [super createBegin: aZone];
-
+  
   // Fill in the relevant parameters (only one, in this case).
-
+  
   obj->displayFrequency = 1;
-
+  
   // Also, build a customized probe map. Without a probe map, the default
   // is to show all variables and messages. Here we choose to
   // customize the appearance of the probe, give a nicer interface.
@@ -56,27 +57,56 @@
   return obj;		// We return the newly created ObserverSwarm
 }
 
+- _updateMousetraps_: window
+{
+  int x, y, size;
+  // draw all the mousetraps 
+  
+  size = [mousetrapModelSwarm getGridSize];
+  for (x = 0; x < size; x++)
+    for (y = 0; y < size; y++)
+      {
+        Mousetrap *trap = [mousetrapModelSwarm getMousetrapAtX: x Y: y];
+
+        if (trap)
+          {
+            if (window)
+              [window drawPointX: x Y: y Color: 1];
+            [trap setDisplayWidget: window];
+          }
+      }
+  return self;
+}
+
+- _displayWindowDeath_: caller
+{
+  [displayWindow drop];
+  displayWindow = nil;
+  [self _updateMousetraps_: nil];
+  return self;
+}
+
 // createEnd: create objects we know we'll need. In this case, none,
 // but you might want to override this.
 
--createEnd {
+- createEnd
+{
   return [super createEnd];
 }
 
-
 // Create the objects used in the display of the model. 
 // Here, we create the objects used in the experiment
 // Primairly, the Mousetrap model itself, but also the
 // various instrumentation that observes the model. 
 
--buildObjects {
+- buildObjects
+{
   id modelZone;					// zone for model
-  int x, y, size;
-
+  
   // Let our superClass build any objects it needs to first
   
   [super buildObjects];
-
+  
   // Then, we create the model that we're actually observing. The
   // model is a subswarm of the observer. We create the model in
   // its own zone, so storage is segregated.
@@ -87,8 +117,8 @@
   // Now create probe objects on the model and ourselves. This gives a
   // simple user interface to let the user change parameters.
   
-  [probeDisplayManager createProbeDisplayFor: mousetrapModelSwarm];
-  [probeDisplayManager createProbeDisplayFor: self];
+  CREATE_ARCHIVED_PROBE_DISPLAY (mousetrapModelSwarm);
+  CREATE_ARCHIVED_PROBE_DISPLAY (self);
 
   // Instruct the control panel to wait for a button event: we halt here
   // until someone hits a control panel button so the user can get a
@@ -115,6 +145,7 @@
   // set up the EZGraph object
   
   triggerGraph = [EZGraph createBegin: [self getZone]];
+  SET_WINDOW_GEOMETRY_RECORD_NAME (triggerGraph);
   [triggerGraph setTitle: "Trigger data vs. time"];
   [triggerGraph setAxisLabelsX: "time" Y: "number triggered"];
   triggerGraph = [triggerGraph createEnd] ;
@@ -135,29 +166,20 @@
   // Next, create a 2d window to display the mousetrap world
   // and  set its size, zoom factor, title.
 
-  displayWindow = [ZoomRaster create: globalZone];
+  displayWindow = [ZoomRaster createBegin: globalZone];
+  SET_WINDOW_GEOMETRY_RECORD_NAME (displayWindow);
+  displayWindow = [displayWindow createEnd];
+  [displayWindow enableDestroyNotification: self
+                 notificationMethod: @selector (_displayWindowDeath_:)];
   [displayWindow setColormap: colormap];
   [displayWindow setZoomFactor: 6];
   [displayWindow setWidth: [mousetrapModelSwarm getGridSize]
 		 Height: [mousetrapModelSwarm getGridSize]];
   [displayWindow setWindowTitle: "Mousetrap World"];
-
-  // draw all the mousetraps 
-
-  size = [mousetrapModelSwarm getGridSize];
-  for (x = 0; x < size; x++)
-    for (y = 0; y < size; y++) {
-      Mousetrap * trap;
-      trap = [mousetrapModelSwarm getMousetrapAtX: x Y: y];
-      if (trap) {
-	[displayWindow drawPointX: x Y: y Color: 1];
-	[trap setDisplayWidget: displayWindow];
-      }
-    }
-	
+  [self _updateMousetraps_: displayWindow];
   [displayWindow drawSelf];
   [displayWindow pack];
-
+  
   // Also create an Object2dDisplay: this object is just used
   // to receive and handle probes on mousetraps.
 
@@ -189,6 +211,13 @@
   return self;
 }  
 
+- _update_
+{
+  if (displayWindow)
+    [displayWindow drawSelf];
+  return self;
+}
+
 // Create the actions necessary for the simulation. This is where
 // the schedule is built (but not run!)
 
@@ -198,8 +227,8 @@
 // will also want to run the model without any display.
 
 
--buildActions {
-
+- buildActions
+{
   // First, let our superclass build any actions
 
   [super buildActions];
@@ -218,7 +247,7 @@
   // Schedule up the methods to draw the display of the world
   //  and to update the graph of the statistics we're keeping
 
-  [displayActions createActionTo: displayWindow       message: M(drawSelf)];
+  [displayActions createActionTo: self                message: M(_update_)];
   [displayActions createActionTo: triggerGraph	      message: M(step)];
 
   // Schedule the update of the probe display
@@ -253,12 +282,12 @@
 // in "nil". But other Swarms and Schedules and such will be activated
 // inside of us.
 
--activateIn: (id) swarmContext {
-
+- activateIn: swarmContext
+{
   // First, activate ourselves (just pass along the context).
-
+  
   [super activateIn: swarmContext];
-
+  
   // Activate the model swarm in ourselves. The model swarm is a
   // subswarm of the observer swarm.
 
@@ -310,20 +339,21 @@
   //   If some other object (like another program) were to control the
   //   activity, then this would be replaced with whatever instantiated
   //   the interface for that object (like a tcp/ip address or a socket).
-  [probeDisplayManager createProbeDisplayFor: observerActCont];
+  CREATE_ARCHIVED_PROBE_DISPLAY (observerActCont);
   
   return [self getSwarmActivity];
 }
 
 // monitor method - if all the balls have landed, time to quit!
 
--checkToStop {
-  if ([[mousetrapModelSwarm getStats] getNumBalls] == 0) {
-    printf("All the balls have landed!\n");
-
-    [controlPanel setStateStopped];
-  }
-
+- checkToStop
+{
+  if ([[mousetrapModelSwarm getStats] getNumBalls] == 0)
+    {
+      printf("All the balls have landed!\n");
+      
+      [controlPanel setStateStopped];
+    }
   return self;
 }
 
