@@ -1,4 +1,4 @@
-// Mousetrap application. Copyright (C) 1996 Santa Fe Institute.
+// Mousetrap application. Copyright (C) 1996-1998 Santa Fe Institute.
 // This library is distributed without any warranty; without even the
 // implied warranty of merchantability or fitness for a particular purpose.
 // See file LICENSE for details and terms of copying.
@@ -23,11 +23,13 @@ main(int argc, char ** argv) {
   // typed mousetrap -batchmode. Otherwise, it's set to 1.
   
   if (swarmGUIMode == 1)
-
-    // We've got graphics, so make a full ObserverSwarm to get GUI objects
-
-    theTopLevelSwarm = [MousetrapObserverSwarm create: globalZone];
-
+    {
+      // We've got graphics, so make a full ObserverSwarm to get GUI objects
+      
+      theTopLevelSwarm = [MousetrapObserverSwarm createBegin: globalZone];
+      SET_WINDOW_GEOMETRY_RECORD_NAME (theTopLevelSwarm);
+      theTopLevelSwarm = [theTopLevelSwarm createEnd];
+    }
   else
 
     // No graphics - make a batchmode swarm and run it.
