@@ -1,4 +1,4 @@
-// Template application. Copyright (C) 1996 Santa Fe Institute.
+// Template application. Copyright (C) 1996-1998 Santa Fe Institute.
 // This library is distributed without any warranty; without even the
 // implied warranty of merchantability or fitness for a particular purpose.
 // See file LICENSE for details and terms of copying.
@@ -44,8 +44,8 @@
   modelZone = [Zone create: [self getZone]];
   templateModelSwarm = [TemplateModelSwarm create: modelZone];
   
-  [probeDisplayManager createProbeDisplayFor: templateModelSwarm];
-  [probeDisplayManager createProbeDisplayFor: self];
+  CREATE_PROBE_DISPLAY (templateModelSwarm);
+  CREATE_PROBE_DISPLAY (self);
 
   [controlPanel waitForControlEvent];
   if ([controlPanel getState] == ControlStateQuit)
